# Peek-Stock
上班偷偷看股票的利器，不會有紅紅綠綠的字體
<img src="https://user-images.githubusercontent.com/108853120/203787734-e00facb7-fbe4-4f36-b3d9-b186c8a0739a.png" alt="Cover" width="70%"/>

## 功能
- 可設定追蹤５個股票代碼
- 瀏覽股票現價以及漲跌幅

## 安裝流程
1. 請先確認有安裝 python 
2. 將專案 clone 到本地 `git clone https://github.com/Nancy-Hsu/Peek-Stock.git`


## 開發工具
- 開發環境: python 3.11.0
- 框架: flask
